import browsersList from '@knapsack/browserslist-config';
import type { TransformOptions } from '@babel/core';

const useESModules = true;

export function getPresetEnv<
  Opt extends {
    modules: false | 'commonjs';
    /**
     * https://babeljs.io/docs/en/babel-preset-env#targets
     */
    targets?:
      | {
          esmodules: true;
        }
      | Record<string, string>
      | string
      | string[];
  },
>(options: Opt): [string, Opt] {
  return [require.resolve('@babel/preset-env'), options];
}

export const presetEnvEs = getPresetEnv({
  modules: false,
  // Exclude transforms that make all code slower; borrowed from https://github.com/facebook/create-react-app/blob/9123aae7a3beaba8b245f73eb0180baa7b2f8411/packages/babel-preset-react-app/create.js#L90
  exclude: ['transform-typeof-symbol'],
  targets: {
    esmodules: true,
  },
});

export const presetEnvCjs = getPresetEnv({
  modules: 'commonjs',
});

export const baseConfig = {
  presets: [
    [
      require.resolve('@babel/preset-react'),
      {
        development: process.env.NODE_ENV !== 'production',
      },
    ],
    [
      require.resolve('@babel/preset-typescript'),
      {
        isTSX: true,
        allExtensions: true,
        jsxPragma: 'React',
      },
    ],
  ],
  plugins: [
    // https://www.npmjs.com/package/babel-plugin-transform-async-to-promises
    require.resolve('babel-plugin-transform-async-to-promises'),
    require.resolve('@babel/plugin-syntax-dynamic-import'),
    require.resolve('@babel/plugin-proposal-object-rest-spread'),
    require.resolve('@babel/plugin-proposal-nullish-coalescing-operator'),
    [
      require.resolve('@babel/plugin-proposal-decorators'),
      {
        decoratorsBeforeExport: true,
      },
    ],
    require.resolve('@babel/plugin-proposal-class-properties'),
    require.resolve('@babel/plugin-proposal-optional-chaining'),
    require.resolve('@babel/plugin-transform-runtime'),
  ].filter(Boolean),
};

export const esBabelConfig = {
  ...baseConfig,
  presets: [...baseConfig.presets, presetEnvEs],
};

export const cjsBabelConfig = {
  ...baseConfig,
  presets: [...baseConfig.presets, presetEnvCjs],
};

export const basicBrowserBabelConfig: TransformOptions = {
  presets: [
    // https://babeljs.io/docs/en/babel-preset-env
    [require.resolve('@babel/preset-env'), { targets: browsersList }],
    [
      // https://babeljs.io/docs/en/babel-preset-typescript
      require.resolve('@babel/preset-typescript'),
      {
        isTSX: true,
        allExtensions: true,
      },
    ],
    [
      // https://babeljs.io/docs/en/babel-preset-react
      require.resolve('@babel/preset-react'),
      {
        development: process.env.NODE_ENV !== 'production',
      },
    ],
  ],
};
